@@ -269,20 +269,6 @@ QString PhoneNumber::toString() const
     return str;
 }
 
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-void PhoneNumber::setParameters(const QMap<QString, QStringList> &params)
-{
-    d->mParamMap = ParameterMap::fromQMap(params);
-}
-#endif
-
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-QMap<QString, QStringList> PhoneNumber::parameters() const
-{
-    return d->mParamMap.toQMap();
-}
-#endif
-
 void PhoneNumber::setParams(const ParameterMap &params)
 {
     d->mParamMap = params;
